summaryrefslogtreecommitdiffstats
path: root/content/browser/tab_contents/tab_contents.h
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-28 22:19:14 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-28 22:19:14 +0000
commitee2ed42c72935932a756dedfe797d96bd0205e31 (patch)
treeaee48705aeabd69a6b7c1b08510c3309484b1561 /content/browser/tab_contents/tab_contents.h
parentad9a072a78fea6d59e142716ca4104687490bfc6 (diff)
downloadchromium_src-ee2ed42c72935932a756dedfe797d96bd0205e31.zip
chromium_src-ee2ed42c72935932a756dedfe797d96bd0205e31.tar.gz
chromium_src-ee2ed42c72935932a756dedfe797d96bd0205e31.tar.bz2
Favicon file shuffling.
Moves them to their own directory, renames the Helper to TabHelper in prep for moving it to TabContentsWrapper. BUG=71097 TEST=none Review URL: http://codereview.chromium.org/6902125 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@83425 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/browser/tab_contents/tab_contents.h')
-rw-r--r--content/browser/tab_contents/tab_contents.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/content/browser/tab_contents/tab_contents.h b/content/browser/tab_contents/tab_contents.h
index 5d3cd23..5fe5e97 100644
--- a/content/browser/tab_contents/tab_contents.h
+++ b/content/browser/tab_contents/tab_contents.h
@@ -15,7 +15,7 @@
#include "base/gtest_prod_util.h"
#include "base/memory/scoped_ptr.h"
#include "base/string16.h"
-#include "chrome/browser/favicon_helper.h"
+#include "chrome/browser/favicon/favicon_tab_helper.h"
#include "chrome/browser/prefs/pref_change_registrar.h"
#include "chrome/browser/tab_contents/tab_specific_content_settings.h"
#include "chrome/browser/ui/app_modal_dialogs/js_modal_dialog.h"
@@ -163,9 +163,9 @@ class TabContents : public PageNavigator,
return view_.get();
}
- // Returns the FaviconHelper of this TabContents.
- FaviconHelper& favicon_helper() {
- return *favicon_helper_.get();
+ // Returns the FaviconTabHelper of this TabContents.
+ FaviconTabHelper& favicon_helper() {
+ return *favicon_tab_helper_.get();
}
// Tab navigation state ------------------------------------------------------
@@ -915,7 +915,7 @@ class TabContents : public PageNavigator,
BookmarkDrag* bookmark_drag_;
// Handles downloading favicons.
- scoped_ptr<FaviconHelper> favicon_helper_;
+ scoped_ptr<FaviconTabHelper> favicon_tab_helper_;
// RenderViewHost::ContentSettingsDelegate.
scoped_ptr<TabSpecificContentSettings> content_settings_delegate_;